"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.translationValue = exports.renderTranslation = exports.renderKey = exports.useBufferOrInjectedTranslations = exports.PluralizedTranslationKeys = void 0;
const theme_check_common_1 = require("@shopify/theme-check-common");
exports.PluralizedTranslationKeys = ['one', 'few', 'many', 'two', 'zero', 'other'];
async function useBufferOrInjectedTranslations(getDefaultTranslationsFactory, theme, rootURI) {
    const injectedGetDefaultTranslations = getDefaultTranslationsFactory(rootURI);
    const defaultTranslationsSourceCode = theme.find((sourceCode) => sourceCode.type === theme_check_common_1.SourceCodeType.JSON &&
        sourceCode.absolutePath.match(/locales/) &&
        sourceCode.absolutePath.match(/default\.json/));
    return (parseDefaultTranslations(defaultTranslationsSourceCode) ||
        (await injectedGetDefaultTranslations()));
}
exports.useBufferOrInjectedTranslations = useBufferOrInjectedTranslations;
function parseDefaultTranslations(sourceCode) {
    if (!sourceCode)
        return undefined;
    try {
        return JSON.parse(sourceCode.source);
    }
    catch (e) {
        return undefined;
    }
}
function renderKey(translation, key) {
    if (translation[key]) {
        return `\`${key}:\` ${translation[key]}`;
    }
}
exports.renderKey = renderKey;
function renderTranslation(translation) {
    if (typeof translation === 'string')
        return translation;
    return [
        renderKey(translation, 'zero'),
        renderKey(translation, 'one'),
        renderKey(translation, 'two'),
        renderKey(translation, 'few'),
        renderKey(translation, 'many'),
        renderKey(translation, 'other'),
    ]
        .filter(Boolean)
        .join('\n\n---\n\n');
}
exports.renderTranslation = renderTranslation;
function translationValue(path, translations) {
    const parts = path.split('.');
    let current = translations;
    for (const key of parts) {
        if (!current || typeof current === 'string') {
            return undefined;
        }
        current = current[key];
    }
    return current;
}
exports.translationValue = translationValue;
//# sourceMappingURL=translations.js.map